window.onload = () => {
	let overview = {
		checks: document.getElementById("overview_checks"),
		entrances: document.getElementById("overview_entrances"),
	};
	let current_scene = {
		name: document.getElementById("current_scene_text"),
		checks: {
			title: document.getElementById("current_scene_checks_title"),
			list: document.getElementById("current_scene_checks_list"),
		},
		entrances: {
			title: document.getElementById("current_scene_entrances_title"),
			list: document.getElementById("current_scene_entrances_list"),
			mapped: document.getElementById("current_scene_entrances_mapped"),
		},
	};
	let line_elem = document
		.getElementById("current_scene_checks_list")
		.firstElementChild.cloneNode(true);
	let mapped_line_elem = document
		.getElementById("current_scene_entrances_mapped")
		.firstElementChild.cloneNode(true);
    
	const refresh_interval = setInterval(
		refresh_elements,
		300,
		overview,
		current_scene,
		line_elem,
		mapped_line_elem
	);
};

async function refresh_elements(
	overview,
	current_scene,
	line_elem,
	mapped_line_elem
) {
	fetch("http://localhost:8000/spoiler")
		.then((response) => response.json())
		.then((data) => {
			const response_object = JSON.parse(JSON.stringify(data));
			const overview_checks_undiscovered =
				response_object.Totals.Checks.Undiscovered;
			const overview_checks_total = response_object.Totals.Checks.Total;
			const overview_entrances_undiscovered =
				response_object.Totals.Entrances.Undiscovered;
			const overview_entrances_total = response_object.Totals.Entrances.Total;
			const current_scene_name = response_object.Current.Scene;
			const current_scene_checks_undiscovered =
				response_object.Scenes[current_scene_name].Totals.Checks.Undiscovered;
			const current_scene_checks_total =
				response_object.Scenes[current_scene_name].Totals.Checks.Total;
			const current_scene_entrances_undiscovered =
				response_object.Scenes[current_scene_name].Totals.Entrances
					.Undiscovered;
			const current_scene_entrances_total =
				response_object.Scenes[current_scene_name].Totals.Entrances.Total;
			const current_scene_checks_list =
				response_object.Scenes[current_scene_name].Checks;
			const current_scene_entrances_list =
				response_object.Scenes[current_scene_name].Entrances;
			overview.checks.textContent = `Checks: ${overview_checks_undiscovered}/${overview_checks_total}`;
			overview.entrances.textContent = `Entrances: ${overview_entrances_undiscovered}/${overview_entrances_total}`;
			current_scene.name.textContent = current_scene_name;
			current_scene.checks.title.textContent = `Checks: ${current_scene_checks_undiscovered}/${current_scene_checks_total}`;
			current_scene.entrances.title.textContent = `Entrances: ${current_scene_entrances_undiscovered}/${current_scene_entrances_total}`;
			current_scene.checks.list.innerHTML = "";
			current_scene.entrances.list.innerHTML = "";
			current_scene.entrances.mapped.innerHTML = "";
			Object.keys(current_scene_checks_list).forEach((check) => {
				if (!current_scene_checks_list[check]) {
					line_elem.textContent = `❌ ${check}`;
					current_scene.checks.list.appendChild(line_elem.cloneNode(true));
				}
			});
			Object.keys(current_scene_entrances_list).forEach((entrances) => {
				if (current_scene_entrances_list[entrances] == "") {
					line_elem.textContent = `❌ ${entrances}`;
					current_scene.entrances.list.appendChild(line_elem.cloneNode(true));
				} else {
					mapped_line_elem.textContent = `✔️ ${entrances} -> ${current_scene_entrances_list[entrances]}`;
					current_scene.entrances.mapped.appendChild(
						mapped_line_elem.cloneNode(true)
					);
				}
			});
		})
		.catch((err) => {
			console.log(err);
		});
}

function log_elements() {
	console.log(overview.checks.textContent);
	console.log(overview.entrances.textContent);
	console.log(current_scene.name.textContent);
	console.log(current_scene.checks.title.textContent);
	for (i in current_scene.checks.list.children) {
		if (current_scene.checks.list.children[i].textContent) {
			console.log(current_scene.checks.list.children[i].textContent);
		}
	}
	console.log(current_scene.entrances.title.textContent);
	for (i in current_scene.entrances.list.children) {
		if (current_scene.entrances.list.children[i].textContent) {
			console.log(current_scene.entrances.list.children[i].textContent);
		}
	}
	for (i in current_scene.entrances.mapped.children) {
		if (current_scene.entrances.mapped.children[i].textContent) {
			console.log(current_scene.entrances.mapped.children[i].textContent);
		}
	}
}
